TURBOMOLE — ASE documentation

### Navigation

- index
- modules |
- Documentation for modules in ASE »
- Calculators »

# TURBOMOLE

## Introduction

TURBOMOLE is a density-functional or Hartree Fock code using atom centered orbitals. This interface makes it possible to use TURBOMOLE as a calculator in ASE.

## Environment variables

Set environment variables in your configuration file:

- bash:

      $ TURBODIR=/my_disk/my_name/TURBOMOLE
      $ PATH=$TURBODIR/scripts:$PATH
      $ PATH=$TURBODIR/bin/sysname:$PATH

- csh/tcsh:

      $ setenv TURBODIR /my_disk/my_name/TURBOMOLE
      $ set path=(${TURBODIR}/scripts $path)
      $ set path=(${TURBODIR}/bin/sysname $path)

where \(sysname\) could be, e.g.: \(x86_64-unknown-linux-gnu\).

## Turbomole Calculator

All usual turbomole input files generated by Turbomole’s define [coord, control, basis, (auxbasis), mos/alpha+beta] must be present in the current working directory.

Turbomole files are updated during the ASE-run.

Do not use internal coordinates, only cartesians are allowed.

Ase-Turbomole uses turbomole programs ‘ridft’ and ‘rdgrad’ if keyword ‘$ricore’ is present in the Turbomole’s control file. Otherwise programs ‘dscf’ and ‘grad’ are used.

## Example1: Single-point energy

Here is an example of how to calculate the total energy of H2 ase/test/turbomole/turbomole_H2.py.

## Example2: NEB

Here is an example of how to calculate a proton transfer barrier in H3O2-: ase/test/turbomole/turbomole_h3o2m.py.

### Navigation

- index
- modules |
- Documentation for modules in ASE »
- Calculators »